@@ -206,6 +206,7 @@ class CameraInput(TypedDict):
     name: str
     roles: list[CameraRoles]
     urls: StreamUrls
+    internal: bool
 
 
 class PrebufferState(TypedDict, total=False):
@@ -721,7 +722,7 @@ class CameraDevice(Protocol):
     @property
     def sources(self) -> list[CameraDeviceSource]: ...
     @property
-    def internal_sources(self) -> list[CameraDeviceSource]: ...
+    def internal_sources(self) -> list[CameraDeviceInternalSource]: ...
 
     @property
     def on_connected(self) -> Observable[bool]: ...
